const fs = require('fs');
const path = require('path');
const mv = require('mv');

const mvPromise = (oldPath, newPath, options) => {
  return new Promise((resolve, reject) => {
    mv(oldPath, newPath, options, (err) => {
      if (err) {
        return reject(err);
      }
  
      return resolve();
    });
  });
};

const main = async () => {
  const directory = process.env.FILES_DIR;

  if (!directory || directory === 'NULL') {
    throw new Error('FILES_DIR environment variable needs to be set.');
  }

  const validDirectory = fs.existsSync(directory) && fs.lstatSync(directory).isDirectory();

  if (!validDirectory) {
    throw new Error('FILES_DIR environment variable needs to point to a valid directory.');
  }

  const absoluteDirectory = path.resolve(directory);

  const folderContent = fs.readdirSync(absoluteDirectory);
  const files = folderContent.filter((file) => path.extname(file));

  if (!files.length) {
    console.log('No files to move.');
    return;
  }

  for (const file of files) {
    const { name } = path.parse(file);
    
    const oldFilename = path.join(absoluteDirectory, file);
    const newFilename = path.join(absoluteDirectory, name, file);

    await mvPromise(oldFilename, newFilename, { mkdirp: true });
    console.log(`Moved ${oldFilename} to ${newFilename}`);
  }
};

main()
  .then(() => {
    process.exit(0);
  })
  .catch((error) => {
    console.error(error);
    process.exit(1);
  });
